//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------
namespace Microsoft.ServiceBus.AccessControlExtensions
{
    using System;
    using AccessControlManagement;

    public class AccessControlRule
    {
        readonly IdentityReference condition;
        readonly bool inherited;
        readonly Right right;
        string description;
        Rule rule;

        internal AccessControlRule(IdentityReference condition, Right right, bool inherited, RuleGroup group, Rule rule)
        {
            this.condition = condition;
            this.right = right;
            this.inherited = inherited;
            this.Group = group;
            this.rule = rule;
        }

        internal AccessControlRule(AccessControlServiceIdentity identity, Right right, bool inherited, RuleGroup group, Rule rule)
        {
            this.condition = IdentityReference.CreateServiceIdentityReference(identity);
            this.right = right;
            this.inherited = inherited;
            this.Group = group;
            this.rule = rule;
        }

        internal Rule Rule
        {
            get { return this.rule; }
            set { this.rule = value; }
        }

        internal RuleGroup Group { get; set; }

        public IdentityReference Condition
        {
            get { return this.condition; }
        }

        public Right Right
        {
            get { return this.right; }
        }

        public string Description
        {
            get { return this.description; }
            set
            {
                if (this.inherited)
                    throw new InvalidOperationException();
                this.description = value;
            }
        }

        public bool Inherited
        {
            get { return this.inherited; }
        }

        internal bool Deleted { get; set; }

        public bool PrepareChanges()
        {
            if (this.rule != null &&
                (this.rule.InputClaimType != this.Condition.ClaimType || this.rule.InputClaimValue != this.Condition.ClaimValue ||
                 this.rule.OutputClaimType != this.Right.ClaimType || this.rule.OutputClaimValue != this.Right.ClaimValue))
            {
                this.rule.InputClaimType = this.Condition.ClaimType;
                this.rule.InputClaimValue = this.Condition.ClaimValue;
                this.rule.OutputClaimType = this.Right.ClaimType;
                this.rule.OutputClaimValue = this.Right.ClaimValue;
                return true;
            }
            else
            {
                return false;
            }
        }
    }
}
