//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------
namespace Microsoft.ServiceBus.AccessControlExtensions
{
    public abstract class ServiceBusRight : Right
    {
        public static readonly Right Listen = new ListenRight();
        public static readonly Right Manage = new ManageRight();
        public static readonly Right Send = new SendRight();

        public new static Right CreateGenericRight(string outputClaimType, string outputClaimValue)
        {
            if (outputClaimType == "net.windows.servicebus.action")
            {
                switch (outputClaimValue)
                {
                    case "Listen":
                        return Listen;
                    case "Send":
                        return Send;
                    case "Manage":
                        return Manage;
                }
            }
            return new GenericRight(outputClaimType, outputClaimValue);
        }

        sealed class ListenRight : ServiceBusRight
        {
            public override string ClaimType
            {
                get { return "net.windows.servicebus.action"; }
            }

            public override string ClaimValue
            {
                get { return "Listen"; }
            }
        }

        sealed class ManageRight : ServiceBusRight
        {
            public override string ClaimType
            {
                get { return "net.windows.servicebus.action"; }
            }

            public override string ClaimValue
            {
                get { return "Manage"; }
            }
        }

        sealed class SendRight : ServiceBusRight
        {
            public override string ClaimType
            {
                get { return "net.windows.servicebus.action"; }
            }

            public override string ClaimValue
            {
                get { return "Send"; }
            }
        }
    }
}
