//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.ServiceBus.Samples
{
    using System;
    using System.ServiceModel;
    using Microsoft.ServiceBus;

    class Program
    {
        static void Main(string[] args)
        {
            Console.Write("Enter the Service Namespace you want to connect to: ");
            string serviceNamespace = Console.ReadLine();

            Uri serviceUri = ServiceBusEnvironment.CreateServiceUri("sb", serviceNamespace, "OnewayService");

            ChannelFactory<IOnewayChannel> channelFactory = new ChannelFactory<IOnewayChannel>("RelayEndpoint", new EndpointAddress(serviceUri));

            IOnewayChannel channel = channelFactory.CreateChannel();
            Console.WriteLine("Opening Channel.");
            channel.Open();

            for (int i = 1; i <= 25; i++)
            {
                Console.WriteLine("Sending: {0}", i);
                channel.Send(i);
            }

            Console.WriteLine("Closing Channel.");
            channel.Close();

            channelFactory.Close();

            Console.WriteLine("Press [Enter] to exit");
            Console.ReadLine();
        }
    }
}
