//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.ServiceBus.Samples
{
    using System;
    using System.Net;
    using System.Text;
    using System.Xml;
    using System.IO;
    using System.ServiceModel.Syndication;
    
    class Program
    {
        static void Main(string[] args)
        {
            Console.Write("Enter the name of the Service Namespace you want to connect to: ");
            string serviceNamespace = Console.ReadLine();

            // WebHttpRelayBinding uses transport security by default
            Uri serviceUri = ServiceBusEnvironment.CreateServiceUri("https", serviceNamespace, "SyndicationService");

            HttpWebRequest request = (HttpWebRequest)WebRequest.Create(serviceUri.ToString());
            HttpWebResponse response = (HttpWebResponse)request.GetResponse();

            Stream stream = response.GetResponseStream();
            XmlReader reader = XmlReader.Create(stream);
            Rss20FeedFormatter formatter = new Rss20FeedFormatter();
            formatter.ReadFrom(reader);

            Console.WriteLine("\nThese are the contents of your feed: ");
            Console.WriteLine(" ");
            Console.WriteLine(formatter.Feed.Title.Text);
            foreach (SyndicationItem item in formatter.Feed.Items)
            {
                Console.WriteLine(item.Title.Text + ": " + item.Summary.Text);
            }

            Console.WriteLine("Press [Enter] to exit");
            Console.ReadLine();
        }
    }
}
