//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.ServiceBus.Samples
{
    using System;
    using System.Threading;
    using System.Management.Automation;
    using Microsoft.ServiceBus.Messaging;

    [Cmdlet("Receive", "Message")]
    public class ReceiveMessageCmdlet : ServiceBusCmdletBase
    {
        [Parameter(
        Mandatory = false,
        HelpMessage = "PeekLock")]
        public SwitchParameter PeekLock { get; set; }

        [Parameter(
        Mandatory = true,
        HelpMessage = "Name of Subscription or queue")]
        public string From
        {
            get;
            set;
        }

        protected override void ProcessRecord()
        {
            string[] chunks = Context.ChunkPath(this.SessionState.Path.CurrentLocation);
            ReceiveMode mode = this.PeekLock.IsPresent ? ReceiveMode.PeekLock : ReceiveMode.ReceiveAndDelete;

            string path = this.From;
            if (chunks[0] == "Topics")
            {
                path = SubscriptionClient.FormatSubscriptionPath(chunks[1], this.From);
            }

            BrokeredMessage message = null;
            MessageReceiver receiver = this.Factory.CreateMessageReceiver(path, mode);
            try
            {
                message = receiver.Receive(TimeSpan.FromSeconds(10));
            }
            finally
            {
                // Setting a timer to close the receiver after a minute. User has to complete the message in this time window
                new Timer(CloseReceiver, (object)receiver, TimeSpan.FromMinutes(1), TimeSpan.FromMilliseconds(-1));
            }

            if (message != null)
            {
                message.Properties.Add("Body", message.GetBody<string>());
            }

            this.WriteObject(message);
        }

        static void CloseReceiver(object state)
        {
            try
            {
                MessageReceiver receiver = state as MessageReceiver;
                if (receiver != null)
                {
                    receiver.Close();
                }
            }
            catch (Exception)
            {
            }
        }
    }
}
