//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.ServiceBus.Samples
{
    using System;
    using System.Management.Automation;
    using Microsoft.ServiceBus.Messaging;

    [Cmdlet("Send", "Message")]
    public class SendMessageCmdlet : ServiceBusCmdletBase
    {
        [Parameter(
        Mandatory = true,
        HelpMessage = "Message to send")]
        public string Message
        {
            get;
            set;
        }

        [Parameter(
        Mandatory = true,
        HelpMessage = "Name of topic or queue")]
        public string To
        {
            get;
            set;
        }
        
        protected override void ProcessRecord()
        {
            string[] chunks = Context.ChunkPath(this.SessionState.Path.CurrentLocation);
            if (chunks.Length > 1)
            {
                this.WriteError(
                    new ErrorRecord(
                        new InvalidOperationException(
                            "Messages can only be sent for queues and topics, make sure you are in that location"),
                        "0",
                        ErrorCategory.InvalidOperation,
                        this.SessionState.Path.CurrentLocation.Path));
            }
            else
            {
                MessageSender sender = this.Factory.CreateMessageSender(this.To);
                try
                {
                    sender.Send(new BrokeredMessage(this.Message));
                }
                finally
                {
                    sender.Close();
                }
            }            
        }
    }
}

