//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.ServiceBus.Samples
{
    using System;
    using System.Configuration;
    using System.ServiceModel;
    using System.ServiceModel.Description;
    using Microsoft.ServiceBus;

    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("CloudTrace Console");
            Console.WriteLine("Connecting ...");

            //Retrieve Settings from App.Config
            string servicePath = ConfigurationManager.AppSettings["CloudTraceServicePath"];
            string serviceNamespace = ConfigurationManager.AppSettings["CloudTraceServiceNamespace"];
            string issuerName = ConfigurationManager.AppSettings["CloudTraceIssuerName"];
            string issuerSecret = ConfigurationManager.AppSettings["CloudTraceIssuerSecret"];

            //Construct a Service Bus URI
            Uri uri = ServiceBusEnvironment.CreateServiceUri("sb", serviceNamespace, servicePath);

            //Create a Behavior for the Credentials
            TransportClientEndpointBehavior sharedSecretServiceBusCredential = new TransportClientEndpointBehavior();
            sharedSecretServiceBusCredential.TokenProvider = TokenProvider.CreateSharedSecretTokenProvider(issuerName, issuerSecret);

            //Create the Service Host 
            ServiceHost host = new ServiceHost(typeof(TraceService), uri);
            ServiceEndpoint serviceEndPoint = host.AddServiceEndpoint(typeof(ITraceContract), new NetEventRelayBinding(), String.Empty);
            serviceEndPoint.Behaviors.Add(sharedSecretServiceBusCredential);
            
            //Open the Host
            host.Open();
            Console.WriteLine("Connected To: " + uri.ToString());
            Console.WriteLine("Hit [Enter] to exit");
            
            //Wait Until the Enter Key is Pressed and Close the Host
            Console.ReadLine();
            host.Close();         
        }
    }
}
