//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.Samples.ServiceBus.SilverlightChat.Models.ValueConverters
{
    using System;
    using System.Windows.Data;

    /// <summary>
    /// Converts a boolean value to a user-specified string.
    /// </summary>
    /// <remarks>
    /// This converter is used to bind from a ChatTopicViewModel's IsSubscribed property to the 
    /// tooltip for the 'star' button next to a topic's name. That is, when the topic does not have
    /// a subscription, the string 'Subsribe to this topic' is displayed in the tooltip, otherwise
    /// the string 'Unsubscribe from this topic' is displayed
    /// </remarks>
    public class BoolToStringConverter : IValueConverter
    {
        public string ValueWhenTrue { get; set; }

        public string ValueWhenFalse { get; set; }

        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return (bool)value ? this.ValueWhenTrue : this.ValueWhenFalse;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotSupportedException();
        }
    }
}
