//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.Samples.ServiceBus.SilverlightChat.Models.ValueConverters
{
    using System;
    using System.Windows.Data;

    /// <summary>
    /// Converts Unescapes a Uri Data String, replacing escape characters like '%20' with ' ', etc.
    /// </summary>
    /// <remarks>
    /// This converter is used to bind from a ChatTopicViewModel's Name property to the 
    /// to the text value displayed in the UI. Since the Topic's name will be encoded as an HTTP 
    /// path, this converter makes turns an unfriendly string like 'App%20Fabric%20Chat' into 
    /// 'App Fabric Chat'
    /// </remarks>
    public class UnescapeUriValueConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return Uri.UnescapeDataString((string)value);
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return Uri.EscapeDataString((string)value);
        }
    }
}
