//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.Samples.ServiceBus.WindowsPhoneChat.Commands
{
    using System;

    public delegate void AsyncCommandEventHandler<T>(object sender, AsyncCommandEventArgs<T> e);

    public class AsyncCommandEventArgs<T>
    {
        private readonly AsyncCommand<T> command;
        private readonly T parameter;
        private readonly bool cancelled;

        public AsyncCommandEventArgs(AsyncCommand<T> command, T parameter)
            : this(command, parameter, false)
        {
        }

        public AsyncCommandEventArgs(AsyncCommand<T> command, T parameter, bool cancelled)
        {
            if (command == null)
            {
                throw new ArgumentNullException("command");
            }

            this.command = command;
            this.parameter = parameter;
            this.cancelled = cancelled;
        }

        public T Parameter
        {
            get { return this.parameter; }
        }

        public AsyncCommand<T> Command
        {
            get { return this.command; }
        }

        public bool Cancelled
        {
            get { return this.cancelled; }
        }
    }
}
