//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.Samples.ServiceBus.WindowsPhoneChat.Commands
{
    using System;
    using System.Linq;
    using Microsoft.Samples.ServiceBus.Messaging;
    using Microsoft.Samples.ServiceBus.WindowsPhoneChat.Controllers;
    using Microsoft.Samples.ServiceBus.WindowsPhoneChat.ViewModels;

    public class RefreshTopicsCommand : Command<ChatTopicListControlViewModel>
    {
        protected override bool CanExecute(ChatTopicListControlViewModel viewModel)
        {
            return viewModel != null;
        }

        protected override void Execute(ChatTopicListControlViewModel viewModel)
        {
            TopicClient.BeginGetTopics(App.Context.TokenProvider, this.OnGetTopicsCompleted, viewModel);
        }

        private void OnGetTopicsCompleted(IAsyncResult result)
        {
            var viewModel = (ChatTopicListControlViewModel)result.AsyncState;
            var topicDescriptions = TopicClient.EndGetTopics(result);
            var topicClients = topicDescriptions.Select(t => new TopicClient(t.Path, App.Context.TokenProvider));

            ViewController.Current.BeginInvokeUI(() => viewModel.UpdateItems(topicClients));
        }
    }
}
