//---------------------------------------------------------------------------------
// Copyright (c) 2011, Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//---------------------------------------------------------------------------------

namespace Microsoft.Samples.ServiceBus.WindowsPhoneChat.ViewModels
{
    using System;
    using Microsoft.Samples.ServiceBus.WindowsPhoneChat.Commands;

    public delegate void ShowDialogEventHandler(object sender, ShowDialogEventArgs e);

    public class ShowDialogEventArgs : EventArgs
    {
        private readonly string dialogName;
        private readonly ViewModel dialogViewModel;
        private readonly DialogCallback callback;
        private readonly object state;

        public ShowDialogEventArgs(string dialogName, ViewModel dialogViewModel, DialogCallback callback, object state)
        {
            if (string.IsNullOrEmpty(dialogName))
            {
                throw new ArgumentNullException("dialogName");
            }

            if (callback == null)
            {
                throw new ArgumentNullException("callback");
            }

            this.dialogName = dialogName;
            this.dialogViewModel = dialogViewModel;
            this.callback = callback;
            this.state = state;
        }

        public string DialogName
        {
            get { return this.dialogName; }
        }

        public ViewModel DialogViewModel
        {
            get { return this.dialogViewModel; }
        }

        public DialogCallback Callback
        {
            get { return this.callback; }
        }

        public object State
        {
            get { return this.state; }
        }
    }
}
